@@ -1,4 +1,4 @@
-from base_request import BaseRequest
+from edgecom.base_request import BaseRequest
 
 
 class ModbusComm(BaseRequest):
